@@ -1,5 +1,5 @@
 from datetime import datetime, timedelta
-from typing import Tuple, Any, Optional
+from typing import Tuple, Any, Optional, List
 import pytz
 from calendar import monthrange
 from django.utils.text import format_lazy
@@ -10,7 +10,9 @@ TIME_RANGE_CHOICES = [
     ('last_month', _('last month')),
     ('last_year', _('last year')),
     ('this_month', _('this month')),
+    ('this_year', _('this year')),
     ('last_week', _('last week')),
+    ('this_week', _('this week')),
     ('yesterday', _('yesterday')),
     ('today', _('today')),
     ('prev_90d', format_lazy('-90 {}', _('number.of.days'))),
@@ -30,29 +32,27 @@ TIME_RANGE_CHOICES = [
     ('next_7d', format_lazy('+7 {}', _('number.of.days'))),
 ]
 
-TIME_STEP_CHOICES = [
-    ('daily', _('daily')),
-    ('weekly', _('weekly')),
-    ('monthly', _('monthly')),
-]
-
 TIME_RANGE_NAMES = list(zip(*TIME_RANGE_CHOICES))[0]
 
+TIME_STEP_DAILY = 'daily'
+TIME_STEP_WEEKLY = 'weekly'
+TIME_STEP_MONTHLY = 'monthly'
+
+TIME_STEP_TYPES = [
+    TIME_STEP_DAILY,
+    TIME_STEP_WEEKLY,
+    TIME_STEP_MONTHLY,
+]
+
+TIME_STEP_CHOICES = [
+    (TIME_STEP_DAILY, _('daily')),
+    (TIME_STEP_WEEKLY, _('weekly')),
+    (TIME_STEP_MONTHLY, _('monthly')),
+]
+
 TIME_STEP_NAMES = list(zip(*TIME_STEP_CHOICES))[0]
 
 
-def get_last_day_of_month(t: datetime) -> int:
-    """
-    Returns day number of the last day of the month
-    :param t: datetime
-    :return: int
-    """
-    tn = t + timedelta(days=32)
-    tn = datetime(year=tn.year, month=tn.month, day=1)
-    tt = tn - timedelta(hours=1)
-    return tt.day
-
-
 def localize_time_range(begin: datetime, end: datetime, tz: Any = None) -> Tuple[datetime, datetime]:
     """
     Localizes time range. Uses pytz.utc if None provided.
@@ -66,33 +66,16 @@ def localize_time_range(begin: datetime, end: datetime, tz: Any = None) -> Tuple
     return tz.localize(begin), tz.localize(end)
 
 
-def this_week(today: Optional[datetime] = None, tz: Any = None) -> Tuple[datetime, datetime]:
+def get_last_day_of_month(t: datetime) -> int:
     """
-    Returns this week begin (inclusive) and end (exclusive).
-    :param today: Some date (defaults current datetime)
-    :param tz: Timezone (defaults pytz UTC)
-    :return: begin (inclusive), end (exclusive)
+    Returns day number of the last day of the month
+    :param t: datetime
+    :return: int
     """
-    if today is None:
-        today = datetime.utcnow()
-    begin = today - timedelta(days=today.weekday())
-    begin = datetime(year=begin.year, month=begin.month, day=begin.day)
-    return localize_time_range(begin, begin + timedelta(days=7), tz)
-
-
-def this_month(today: Optional[datetime] = None, tz: Any = None) -> Tuple[datetime, datetime]:
-    """
-    Returns current month begin (inclusive) and end (exclusive).
-    :param today: Some date in the month (defaults current datetime)
-    :param tz: Timezone (defaults pytz UTC)
-    :return: begin (inclusive), end (exclusive)
-    """
-    if today is None:
-        today = datetime.utcnow()
-    begin = datetime(day=1, month=today.month, year=today.year)
-    end = begin + timedelta(days=32)
-    end = datetime(day=1, month=end.month, year=end.year)
-    return localize_time_range(begin, end, tz)
+    tn = t + timedelta(days=32)
+    tn = datetime(year=tn.year, month=tn.month, day=1)
+    tt = tn - timedelta(hours=1)
+    return tt.day
 
 
 def end_of_month(today: Optional[datetime] = None, n: int = 0, tz: Any = None) -> datetime:
@@ -121,6 +104,51 @@ def end_of_month(today: Optional[datetime] = None, n: int = 0, tz: Any = None) -
     return tz.localize(end_incl)
 
 
+def this_week(today: Optional[datetime] = None, tz: Any = None) -> Tuple[datetime, datetime]:
+    """
+    Returns this week begin (inclusive) and end (exclusive).
+    Week is assumed to start from Monday (ISO).
+    :param today: Some date (defaults current datetime)
+    :param tz: Timezone (defaults pytz UTC)
+    :return: begin (inclusive), end (exclusive)
+    """
+    if today is None:
+        today = datetime.utcnow()
+    begin = today - timedelta(days=today.weekday())
+    begin = datetime(year=begin.year, month=begin.month, day=begin.day)
+    return localize_time_range(begin, begin + timedelta(days=7), tz)
+
+
+def this_month(today: Optional[datetime] = None, tz: Any = None) -> Tuple[datetime, datetime]:
+    """
+    Returns current month begin (inclusive) and end (exclusive).
+    :param today: Some date in the month (defaults current datetime)
+    :param tz: Timezone (defaults pytz UTC)
+    :return: begin (inclusive), end (exclusive)
+    """
+    if today is None:
+        today = datetime.utcnow()
+    begin = datetime(day=1, month=today.month, year=today.year)
+    end = begin + timedelta(days=32)
+    end = datetime(day=1, month=end.month, year=end.year)
+    return localize_time_range(begin, end, tz)
+
+
+def this_year(today: Optional[datetime] = None, tz: Any = None) -> Tuple[datetime, datetime]:
+    """
+    Returns this year begin (inclusive) and end (exclusive).
+    :param today: Some date (defaults current datetime)
+    :param tz: Timezone (defaults pytz UTC)
+    :return: begin (inclusive), end (exclusive)
+    """
+    if today is None:
+        today = datetime.utcnow()
+    begin = datetime(day=1, month=1, year=today.year)
+    next_year = today + timedelta(days=365)
+    end = datetime(day=1, month=1, year=next_year.year)
+    return localize_time_range(begin, end, tz)
+
+
 def next_week(today: Optional[datetime] = None, tz: Any = None) -> Tuple[datetime, datetime]:
     """
     Returns next week begin (inclusive) and end (exclusive).
@@ -266,3 +294,37 @@ def per_month(start: datetime, end: datetime, n: int = 1):
         curr_end = add_month(curr, n)
         yield curr, curr_end
         curr = curr_end
+
+
+def get_time_steps(step_type: str, begin: datetime, end: datetime) -> List[Tuple[datetime, datetime]]:
+    """
+    Returns time stamps by time step type [TIME_STEP_DAILY, TIME_STEP_WEEKLY, TIME_STEP_MONTHLY].
+    For example daily steps for a week returns 7 [begin, end) ranges for each day of the week.
+    :param step_type: One of TIME_STEP_DAILY, TIME_STEP_WEEKLY, TIME_STEP_MONTHLY
+    :param begin: datetime
+    :param end: datetime
+    :return: List of [begin, end), one for reach time step unit
+    """
+    after_end = end
+    if TIME_STEP_DAILY == step_type:
+        after_end += timedelta(days=1)
+    elif TIME_STEP_WEEKLY == step_type:
+        after_end += timedelta(days=7)
+    elif TIME_STEP_MONTHLY == step_type:
+        after_end = add_month(end)
+    else:
+        raise ValueError('Time step "{}" not one of {}'.format(step_type, TIME_STEP_TYPES))
+
+    begins: List[datetime] = []
+    t0 = t = begin
+    n = 1
+    while t < after_end:
+        begins.append(t)
+        if step_type == TIME_STEP_DAILY:
+            t = t0 + timedelta(days=n)
+        elif step_type == TIME_STEP_WEEKLY:
+            t = t0 + timedelta(days=7*n)
+        elif step_type == TIME_STEP_MONTHLY:
+            t = add_month(t0, n)
+        n += 1
+    return [(begins[i], begins[i+1]) for i in range(len(begins)-1)]
